@@ -18,6 +18,7 @@
 
 #include <QMutex>
 #include <QMutexLocker>
+#include <QRegularExpression>
 #include <QString>
 #include <QMap>
 
@@ -79,7 +80,7 @@ bool GettextStorage::save(QIODevice* device, bool belongsToProject)
                      m_generatedFromDocbook,
                      belongsToProject,
                      /*forSaving*/true,
-                     m_codec);
+                     QStringLiteral("utf-8")); // we unconditionally write out as UTF-8
     }
     m_header.setMsgstr(header);
     m_header.setComment(comment);
@@ -88,7 +89,7 @@ bool GettextStorage::save(QIODevice* device, bool belongsToProject)
     GettextExportPlugin exporter(Project::instance()->wordWrap(), m_trailingNewLines);
 
     ConversionStatus status = OK;
-    status = exporter.save(device/*x-gettext-translation*/, this, m_codec);
+    status = exporter.save(device/*x-gettext-translation*/, this);
 
     return status == OK;
 }
@@ -239,7 +240,7 @@ QStringList GettextStorage::targetAllForms(const DocPosition& pos, bool stripNew
 
 QVector<AltTrans> GettextStorage::altTrans(const DocPosition& pos) const
 {
-    static const QRegExp alt_trans_mark_re(QStringLiteral("^#\\|"));
+    static const QRegularExpression alt_trans_mark_re(QStringLiteral("^#\\|"));
     QStringList prev = m_entries.at(pos.entry).comment().split(QLatin1Char('\n')).filter(alt_trans_mark_re);
 
     QString oldSingular;
@@ -258,7 +259,7 @@ QVector<AltTrans> GettextStorage::altTrans(const DocPosition& pos) const
             if (!cur->isEmpty())
                 (*cur) += QLatin1Char('\n');
             if (!(cur->isEmpty() && (end - start) == 0)) //for multiline msgs
-                (*cur) += it->midRef(start, end - start);
+                (*cur) += QStringView(*it).mid(start, end - start);
         }
         ++it;
     }
@@ -298,7 +299,7 @@ Note GettextStorage::setNote(DocPosition pos, const Note& note)
     return oldNote;
 }
 
-QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegExp& re, int preLen) const
+QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegularExpression& re, int preLen) const
 {
     QVector<Note> result;
     QString content;
@@ -307,7 +308,7 @@ QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegEx
 
     for (const QString &s : note) {
         if (s.size() >= preLen) {
-            content += s.midRef(preLen);
+            content += QStringView(s).mid(preLen);
             content += QLatin1Char('\n');
         }
     }
@@ -324,13 +325,13 @@ QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegEx
 
 QVector<Note> GettextStorage::notes(const DocPosition& docPosition) const
 {
-    static const QRegExp nre(QStringLiteral("^# "));
+    static const QRegularExpression nre(QStringLiteral("^# "));
     return notes(docPosition, nre, 2);
 }
 
 QVector<Note> GettextStorage::developerNotes(const DocPosition& docPosition) const
 {
-    static const QRegExp dnre(QStringLiteral("^#\\. (?!i18n: file:)"));
+    static const QRegularExpression dnre(QStringLiteral("^#\\. (?!i18n: file:)"));
     return notes(docPosition, dnre, 3);
 }
 
@@ -339,21 +340,21 @@ QStringList GettextStorage::sourceFiles(const DocPosition& pos) const
     QStringList result;
     QStringList commentLines = m_entries.at(pos.entry).comment().split(QLatin1Char('\n'));
 
-    static const QRegExp i18n_file_re(QStringLiteral("^#. i18n: file: "));
+    static const QRegularExpression i18n_file_re(QStringLiteral("^#. i18n: file: "));
     const auto uiLines = commentLines.filter(i18n_file_re);
     for (const QString &uiLine : uiLines) {
-        const auto fileRefs = uiLine.midRef(15).split(QLatin1Char(' '));
-        for (const QStringRef &fileRef : fileRefs) {
+        const auto fileRefs = QStringView(uiLine).mid(15).split(QLatin1Char(' '));
+        for (const auto &fileRef : fileRefs) {
             result << fileRef.toString();
         }
     }
 
     bool hasUi = !result.isEmpty();
-    static const QRegExp cpp_re(QStringLiteral("^#: "));
+    static const QRegularExpression cpp_re(QStringLiteral("^#: "));
     const auto cppLines = commentLines.filter(cpp_re);
     for (const QString &cppLine : cppLines) {
-        const auto fileRefs = cppLine.midRef(3).split(QLatin1Char(' '));
-        for (const QStringRef &fileRef : fileRefs) {
+        const auto fileRefs = QStringView(cppLine).mid(3).split(QLatin1Char(' '));
+        for (const auto &fileRef : fileRefs) {
             if (hasUi && fileRef.startsWith(QLatin1String("rc.cpp:"))) {
                 continue;
             }
@@ -445,7 +446,7 @@ bool GettextStorage::setHeader(const CatalogItem& newHeader)
                      m_generatedFromDocbook,
                      belongsToProject,
                      /*forSaving*/true,
-                     m_codec);
+                     QString::fromLatin1(m_codec));
         m_header = newHeader;
         m_header.setComment(comment);
         m_header.setMsgstr(values);
