@@ -170,7 +170,7 @@ void DBPropertiesDialog::accept()
         return;
 
     if (connectionBox->isVisible()) {
-        QFile rdb(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + name->text() + QLatin1String(REMOTETM_DATABASE_EXTENSION));
+        QFile rdb(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + name->text() + QLatin1String(REMOTETM_DATABASE_EXTENSION));
         if (!rdb.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate))
             return;
 
